# 从 𝓫𝓲𝓵𝓲𝓵𝓲 迁移

## 取消的功能

- `- bilibili` 目录的生成
- 播放列表生成
- 源格式修改功能（不再支持 flv 源视频下载，如果仍有视频不支持 dash 源，请继续使用 bilili）
- 对 Python3.8 的支持，最低支持 Python3.9
- 下载前询问

## 默认行为的修改

- 使用协程而非多线程进行下载
- 默认生成弹幕为 ASS
- 默认启用从多镜像源下载的特性
- 不仅可以控制是否使用系统代理，还能配置特定的代理服务器

## 参数名修改

- 「视频清晰度选择」 `-q`/`--quality` 修改为 `-q`/`--video-quality`
- 「个人信息认证」 `-c`/`--sess-data` 修改为 `-c`/`--sessdata`
- 「指定下载弹幕类型」 `--danmaku` 拆分为「弹幕格式选择」 `-df`/`--danmaku-format` 和「不生成弹幕文件」 `--no-danmaku` 两个参数
- 「绕过系统代理」 `--disable-proxy` 集成到更为灵活的「代理设置」 `-x`/`--proxy` 参数

## 新增的特性

- 单视频下载与批量下载命令分离（`bilili` 命令与 `yutto --batch` 相类似）
- 音频/视频编码选择
- 可选仅下载音频/视频
- 存放子路径的自由定制
- 支持 url 别名
- 支持文件列表
- 更多的批下载支持（现已支持 UP 主全部投稿视频、视频合集、收藏夹等）
- 更加完善的 warning 与 error 提示
- 支持仅输入 id 即可下载（aid、bvid、episode_id 等）
- 支持描述文件生成
- 并行化链接解析（超快的～）
